@@ -178,7 +178,6 @@ capture_offline(const char *infile, const char *outfile)
     // Check if file is standard input
     if (strlen(infile) == 1 && *infile == '-') {
         infile = "/dev/stdin";
-        fstdin = freopen("/dev/tty", "r", stdin);
     }
 
     // Set capture input file
@@ -190,6 +189,14 @@ capture_offline(const char *infile, const char *outfile)
         return 1;
     }
 
+    // Reopen tty for ncurses after pcap have used stdin
+    if (!strncmp(infile, "/dev/stdin", 10)) {
+        if (!(stdin = freopen("/dev/tty", "r", stdin))) {
+            fprintf(stderr, "Failed to reopen tty while using stdin for capture.");
+            return 1;
+        }
+    }
+
     // Get datalink to parse packets correctly
     capinfo->link = pcap_datalink(capinfo->handle);
 
@@ -808,7 +815,12 @@ capture_close()
         //Close PCAP file
         if (capinfo->handle) {
             if (capinfo->running) {
+                /* We must cancel the thread here instead of joining because, according to pcap_breakloop man page,
+                 * you can only break pcap_loop from within the same thread.
+                 * @see: https://www.tcpdump.org/manpages/pcap_breakloop.3pcap.html
+                 */
                 pcap_breakloop(capinfo->handle);
+                pthread_cancel(capinfo->capture_t);
                 pthread_join(capinfo->capture_t, NULL);
             }
         }
@@ -917,7 +929,7 @@ capture_paused()
 const char *
 capture_status_desc()
 {
-    int online = 0, offline = 0;
+    int online = 0, offline = 0, loading = 0;
 
 
     capture_info_t *capinfo;
@@ -925,6 +937,9 @@ capture_status_desc()
     while ((capinfo = vector_iterator_next(&it))) {
         if (capinfo->infile) {
             offline++;
+            if (capinfo->running) {
+                loading++;
+            }
         } else {
             online++;
         }
@@ -945,6 +960,14 @@ capture_status_desc()
         } else {
             return "Mixed (Paused)";
         }
+    } else if (loading > 0) {
+        if (online > 0 && offline == 0) {
+            return "Online (Loading)";
+        } else if (online == 0 && offline > 0) {
+            return "Offline (Loading)";
+        } else {
+            return "Mixed (Loading)";
+        }
     } else {
         if (online > 0 && offline == 0) {
             return "Online";
@@ -1048,12 +1071,6 @@ capture_packet_time_sorter(vector_t *vector, void *item)
 
     // TODO Implement multiframe packets
     curts = packet_time(item);
-    prevts = packet_time(vector_last(vector));
-
-    // Check if the item is already sorted
-    if (timeval_is_older(curts, prevts)) {
-        return;
-    }
 
     for (i = count - 2 ; i >= 0; i--) {
         // Get previous packet
