@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2018 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2018 Irontec SL. All rights reserved.
  ** Copyright (C) 2012 Homer Project (http://www.sipcapture.org)
  **
  ** This program is free software: you can redistribute it and/or modify
@@ -174,6 +174,18 @@ capture_eep_deinit()
     }
 }
 
+const char *
+capture_eep_send_port()
+{
+    return eep_cfg.capt_port;
+}
+
+const char *
+capture_eep_listen_port()
+{
+    return eep_cfg.capt_srv_port;
+}
+
 int
 capture_eep_send(packet_t *pkt)
 {
