@@ -330,10 +330,11 @@ call_list_draw_footer(ui_t *ui)
         key_action_key_str(ACTION_CLEAR_CALLS), "Clear",
         key_action_key_str(ACTION_SHOW_FILTERS), "Filter",
         key_action_key_str(ACTION_SHOW_SETTINGS), "Settings",
+        key_action_key_str(ACTION_CLEAR_CALLS_SOFT), "Clear with Filter",
         key_action_key_str(ACTION_SHOW_COLUMNS), "Columns"
     };
 
-    ui_draw_bindings(ui, keybindings, 22);
+    ui_draw_bindings(ui, keybindings, 23);
 }
 
 void
@@ -672,6 +673,12 @@ call_list_handle_key(ui_t *ui, int key)
                 // Clear List
                 call_list_clear(ui);
                 break;
+            case ACTION_CLEAR_CALLS_SOFT:
+                // Remove stored calls, keeping the currently displayed calls
+                sip_calls_clear_soft();
+                // Clear List
+                call_list_clear(ui);
+                break;
             case ACTION_AUTOSCROLL:
                 info->autoscroll = (info->autoscroll) ? 0 : 1;
                 break;
@@ -740,7 +747,7 @@ int
 call_list_handle_form_key(ui_t *ui, int key)
 {
     int field_idx;
-    char dfilter[COLS];
+    char *dfilter;
     int action = -1;
 
     // Get panel information
@@ -810,13 +817,16 @@ call_list_handle_form_key(ui_t *ui, int key)
     form_driver(info->form, REQ_VALIDATION);
 
     // Store dfilter input
-    // We trim spaces with sscanf because and empty field is stored as space characters
-    memset(dfilter, 0, sizeof(dfilter));
-    strcpy(dfilter, field_buffer(info->fields[FLD_LIST_FILTER], 0));
+    int field_len = strlen(field_buffer(info->fields[FLD_LIST_FILTER], 0));
+    dfilter = malloc(field_len + 1);
+    memset(dfilter, 0, field_len + 1);
+    strncpy(dfilter, field_buffer(info->fields[FLD_LIST_FILTER], 0), field_len);
+    // Trim any trailing spaces
     strtrim(dfilter);
 
     // Set display filter
     filter_set(FILTER_CALL_LIST, strlen(dfilter) ? dfilter : NULL);
+    free(dfilter);
 
     // Return if this panel has handled or not the key
     return (action == ERR) ? KEY_NOT_HANDLED : KEY_HANDLED;
