@@ -90,6 +90,7 @@ enum setting_id {
     SETTING_CAPTURE_STORAGE,
     SETTING_CAPTURE_ROTATE,
     SETTING_SIP_NOINCOMPLETE,
+    SETTING_SIP_HEADER_X_CID,
     SETTING_SIP_CALLS,
     SETTING_SAVEPATH,
     SETTING_DISPLAY_ALIAS,
@@ -110,6 +111,7 @@ enum setting_id {
     SETTING_CF_ONLYMEDIA,
     SETTING_CF_DELTA,
     SETTING_CR_SCROLLSTEP,
+    SETTING_CR_NON_ASCII,
     SETTING_FILTER_PAYLOAD,
     SETTING_FILTER_METHODS,
 #ifdef USE_EEP
