@@ -139,7 +139,9 @@ sip_code_t sip_codes[] = {
 void
 sip_init(int limit, int only_calls, int no_incomplete)
 {
-    int match_flags;
+    int match_flags, reg_rule_len, reg_rule_err;
+    char reg_rule[SIP_ATTR_MAXLEN];
+    const char *setting = NULL;
 
     // Store capture limit
     calls.limit = limit;
@@ -168,9 +170,27 @@ sip_init(int limit, int only_calls, int no_incomplete)
 
     // Initialize payload parsing regexp
     match_flags = REG_EXTENDED | REG_ICASE | REG_NEWLINE;
-    regcomp(&calls.reg_method, "^([a-zA-Z]+) [a-zA-Z]+:[^ ]+ SIP/2.0[ ]*\r", match_flags & ~REG_NEWLINE);
+    regcomp(&calls.reg_method, "^([a-zA-Z]+) [a-zA-Z]+:.+ SIP/2.0[ ]*\r", match_flags & ~REG_NEWLINE);
     regcomp(&calls.reg_callid, "^(Call-ID|i):[ ]*([^ ]+)[ ]*\r$", match_flags);
-    regcomp(&calls.reg_xcallid, "^(X-Call-ID|X-CID):[ ]*([^ ]+)[ ]*\r$", match_flags);
+    setting = setting_get_value(SETTING_SIP_HEADER_X_CID);
+    reg_rule_len = strlen(setting) + 22;
+    if (reg_rule_len >= SIP_ATTR_MAXLEN) {
+        setting = "X-Call-ID|X-CID";
+        reg_rule_len = strlen(setting) + 22;
+        fprintf(stderr, "%s setting too long, using default.\n",
+            setting_name(SETTING_SIP_HEADER_X_CID));
+    }
+    snprintf(reg_rule, reg_rule_len, "^(%s):[ ]*([^ ]+)[ ]*\r$", setting);
+    reg_rule_err = regcomp(&calls.reg_xcallid, reg_rule, match_flags);
+    if(reg_rule_err != 0) {
+        regerror(reg_rule_err, &calls.reg_xcallid, reg_rule, SIP_ATTR_MAXLEN);
+        regfree(&calls.reg_xcallid);
+        fprintf(stderr, "%s setting produces regex compilation error: %s"
+            "using default value instead\n",
+            setting_name(SETTING_SIP_HEADER_X_CID), reg_rule);
+        regcomp(&calls.reg_xcallid,
+            "^(X-Call-ID|X-CID):[ ]*([^ ]+)[ ]*\r$", match_flags);
+    }
     regcomp(&calls.reg_response, "^SIP/2.0[ ]*(([0-9]{3}) [^\r]*)[ ]*\r", match_flags & ~REG_NEWLINE);
     regcomp(&calls.reg_cseq, "^CSeq:[ ]*([0-9]+) .+\r$", match_flags);
     regcomp(&calls.reg_from, "^(From|f):[ ]*[^:]*:(([^@>]+)@?[^\r>;]+)", match_flags);
@@ -470,6 +490,12 @@ sip_calls_vector()
     return calls.list;
 }
 
+vector_t *
+sip_active_calls_vector()
+{
+    return calls.active;
+}
+
 sip_stats_t
 sip_calls_stats()
 {
@@ -500,8 +526,8 @@ int
 sip_get_msg_reqresp(sip_msg_t *msg, const u_char *payload)
 {
     regmatch_t pmatch[3];
-    char resp_str[256];
-    char reqresp[40];
+    char resp_str[SIP_ATTR_MAXLEN];
+    char reqresp[SIP_ATTR_MAXLEN];
     char cseq[11];
     const char *resp_def;
 
@@ -515,7 +541,11 @@ sip_get_msg_reqresp(sip_msg_t *msg, const u_char *payload)
 
         // Method & CSeq
         if (regexec(&calls.reg_method, (const char *)payload, 2, pmatch, 0) == 0) {
-            sprintf(reqresp, "%.*s", (int)(pmatch[1].rm_eo - pmatch[1].rm_so), payload + pmatch[1].rm_so);
+            if ((int)(pmatch[1].rm_eo - pmatch[1].rm_so) >= SIP_ATTR_MAXLEN) {
+                strncpy(reqresp, "<malformed>", 11);
+            } else {
+                sprintf(reqresp, "%.*s", (int) (pmatch[1].rm_eo - pmatch[1].rm_so), payload + pmatch[1].rm_so);
+            }
         }
 
         // CSeq
@@ -527,8 +557,16 @@ sip_get_msg_reqresp(sip_msg_t *msg, const u_char *payload)
 
         // Response code
         if (regexec(&calls.reg_response, (const char *)payload, 3, pmatch, 0) == 0) {
-            sprintf(resp_str, "%.*s", (int)(pmatch[1].rm_eo - pmatch[1].rm_so), payload + pmatch[1].rm_so);
-            sprintf(reqresp, "%.*s", (int)(pmatch[2].rm_eo - pmatch[2].rm_so), payload + pmatch[2].rm_so);
+            if ((int)(pmatch[1].rm_eo - pmatch[1].rm_so) >= SIP_ATTR_MAXLEN) {
+                strncpy(resp_str, "<malformed>", 11);
+            } else {
+                sprintf(resp_str, "%.*s", (int) (pmatch[1].rm_eo - pmatch[1].rm_so), payload + pmatch[1].rm_so);
+            }
+            if ((int)(pmatch[2].rm_eo - pmatch[2].rm_so) >= SIP_ATTR_MAXLEN) {
+                strncpy(resp_str, "<malformed>", 11);
+            } else {
+                sprintf(reqresp, "%.*s", (int) (pmatch[2].rm_eo - pmatch[2].rm_so), payload + pmatch[2].rm_so);
+            }
         }
 
         // Get Request/Response Code
@@ -630,7 +668,8 @@ sip_parse_msg_media(sip_msg_t *msg, const u_char *payload)
     while ((line = strsep(&payload2, "\r\n")) != NULL) {
         // Check if we have a media string
         if (!strncmp(line, "m=", 2)) {
-            if (sscanf(line, "m=%s %hu RTP/%*s %u", media_type, &dst.port, &media_fmt_pref) == 3) {
+            if (sscanf(line, "m=%s %hu RTP/%*s %u", media_type, &dst.port, &media_fmt_pref) == 3
+            ||  sscanf(line, "m=%s %hu UDP/%*s %u", media_type, &dst.port, &media_fmt_pref) == 3) {
 
                 // Add streams from previous 'm=' line to the call
                 ADD_STREAM(msg_rtp_stream);
@@ -725,11 +764,33 @@ sip_calls_clear()
     // Create again the callid hash table
     htable_destroy(calls.callids);
     calls.callids = htable_create(calls.limit);
+
     // Remove all items from vector
     vector_clear(calls.list);
     vector_clear(calls.active);
 }
 
+void
+sip_calls_clear_soft()
+{
+        // Create again the callid hash table
+        htable_destroy(calls.callids);
+        calls.callids = htable_create(calls.limit);
+
+        // Repopulate list applying current filter
+        calls.list = vector_copy_if(sip_calls_vector(), filter_check_call);
+        calls.active = vector_copy_if(sip_active_calls_vector(), filter_check_call);
+
+        // Repopulate callids based on filtered list
+        sip_call_t *call;
+        vector_iter_t it = vector_iterator(calls.list);
+
+        while ((call = vector_iterator_next(&it)))
+        {
+                htable_insert(calls.callids, call->callid, call);
+        }
+}
+
 void
 sip_calls_rotate()
 {
@@ -905,13 +966,6 @@ sip_list_sorter(vector_t *vector, void *item)
     if (vector_count(vector) == 1)
         return;
 
-    prev = vector_item(vector, vector_count(vector) - 2);
-
-    // Check if the item is already sorted
-    if (call_attr_compare(cur, prev, calls.sort.by) == 0) {
-        return;
-    }
-
     for (i = count - 2 ; i >= 0; i--) {
         // Get previous item
         prev = vector_item(vector, i);
