@@ -61,14 +61,14 @@ enum sip_methods {
     SIP_METHOD_NOTIFY,
     SIP_METHOD_OPTIONS,
     SIP_METHOD_PUBLISH,
+    SIP_METHOD_INFO,
+    SIP_METHOD_REFER,
+    SIP_METHOD_UPDATE,
     SIP_METHOD_MESSAGE,
     SIP_METHOD_CANCEL,
     SIP_METHOD_BYE,
     SIP_METHOD_ACK,
     SIP_METHOD_PRACK,
-    SIP_METHOD_INFO,
-    SIP_METHOD_REFER,
-    SIP_METHOD_UPDATE,
 };
 
 //! Return values for sip_validate_packet
@@ -284,6 +284,12 @@ sip_call_is_active(sip_call_t *call);
 vector_t *
 sip_calls_vector();
 
+/**
+ * @brief Return the active call list
+ */
+vector_t *
+sip_active_calls_vector();
+
 /**
  * @brief Return stats from call list
  *
@@ -333,6 +339,15 @@ sip_parse_extra_headers(sip_msg_t *msg, const u_char *payload);
 void
 sip_calls_clear();
 
+/**
+ * @brief Remove al calls
+ *
+ * This funtion will clear the call list of calls other than ones
+ * fitting the current filter
+ */
+void
+sip_calls_clear_soft();
+
 /**
  * @brief Remove first call in the call list
  *
